@@ -1,6 +1,8 @@
 # Taken from Python 2.7
 import sys
 
+from cmsutils.adminfilters import QueryStringManager as QueryStringManagerCMSUtils
+
 
 def _resolve_name(name, package, level):
     """Return the absolute name of the module to be imported."""
@@ -38,3 +40,10 @@ def import_module(name, package=None):
 
 def search_button_submitted(request):
     return request.GET.get('__search_action', None) is not None
+
+
+class QueryStringManager(QueryStringManagerCMSUtils):
+
+    def sanitize_filters(self, filters):
+        from searchform.forms import sanitize_filters
+        return sanitize_filters(filters)
